@@ -10,5 +10,7 @@ from sacrerouge.metrics.pyreval import PyrEval
 from sacrerouge.metrics.python_rouge import PythonRouge
 from sacrerouge.metrics.qaeval import QAEval
 from sacrerouge.metrics.rouge import Rouge
+from sacrerouge.metrics.s3 import S3
 from sacrerouge.metrics.simetrix import SIMetrix
 from sacrerouge.metrics.sumqe import SumQE
+from sacrerouge.metrics.supert import SUPERT
